==> hbase-server-0.96.1-hadoop2-sources.jar: org/apache/hadoop/hbase/ipc/MetricsHBaseServerWrapperImpl.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.ipc;

public class MetricsHBaseServerWrapperImpl implements MetricsHBaseServerWrapper {

  private RpcServer server;

  MetricsHBaseServerWrapperImpl(RpcServer server) {
    this.server = server;
  }

  @Override
  public long getTotalQueueSize() {
    if (this.server == null) {
      return 0;
    }
    return server.callQueueSize.get();
  }

  @Override
  public int getGeneralQueueLength() {
    if (this.server == null || this.server.callQueue == null) {
      return 0;
    }
    return server.callQueue.size();
  }

  @Override
  public int getReplicationQueueLength() {
    if (this.server == null || this.server.replicationQueue == null) {
      return 0;
    }
    return server.replicationQueue.size();
  }

  @Override
  public int getPriorityQueueLength() {
    if (this.server == null || this.server.priorityCallQueue == null) {
      return 0;
    }
    return server.priorityCallQueue.size();
  }

  @Override
  public int getNumOpenConnections() {
    if (this.server == null || this.server.connectionList == null) {
      return 0;
    }
    return server.connectionList.size();
  }
}

==> hbase-server-0.98.5-hadoop2-sources.jar: org/apache/hadoop/hbase/ipc/MetricsHBaseServerWrapperImpl.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.ipc;

public class MetricsHBaseServerWrapperImpl implements MetricsHBaseServerWrapper {

  private RpcServer server;

  MetricsHBaseServerWrapperImpl(RpcServer server) {
    this.server = server;
  }

  @Override
  public long getTotalQueueSize() {
    if (this.server == null) {
      return 0;
    }
    return server.callQueueSize.get();
  }

  @Override
  public int getGeneralQueueLength() {
    if (this.server == null || this.server.getScheduler() == null) {
      return 0;
    }
    return server.getScheduler().getGeneralQueueLength();
  }

  @Override
  public int getReplicationQueueLength() {
    if (this.server == null || this.server.getScheduler() == null) {
      return 0;
    }
    return server.getScheduler().getReplicationQueueLength();
  }

  @Override
  public int getPriorityQueueLength() {
    if (this.server == null || this.server.getScheduler() == null) {
      return 0;
    }
    return server.getScheduler().getPriorityQueueLength();
  }

  @Override
  public int getNumOpenConnections() {
    if (this.server == null || this.server.connectionList == null) {
      return 0;
    }
    return server.connectionList.size();
  }

  @Override
  public int getActiveRpcHandlerCount() {
    if (this.server == null || this.server.getScheduler() == null) {
      return 0;
    }
    return server.getScheduler().getActiveRpcHandlerCount();
  }
}
